@@ -556,34 +556,25 @@ class DataTransform(forms.ModelForm):
             if self.instance.get_children().count() >= 0:
                 print('Adding to child form node: ' + str(self.instance.get_children().count() + 1))
 
-                # dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
-                #                                                      fk_name='parent', form=DataTransform,
-                #                                                      extra=self.instance.get_children().count() + 1,
-                #                                                      can_delete_extra=True
-                #                                                      )
+
                 self.nested_data_transformer_form = dataTransformerInlineFormset(
                     instance=self.instance,
                     queryset=self.instance.get_children(),
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
-                    initial=[{'parent': self.instance, 'accessory': self.instance.accessory, 'id': str(uuid.uuid4())}]
+                    initial=[{'parent': self.instance, 'accessory': self.instance.accessory, 'id':str(uuid.uuid4())}],
+                    prefix=self.instance.id
                 )
                 self.nested_data_transformer_form.extra = self.instance.get_children().count() + 1
-            else:
 
-                self.nested_data_transformer_form = dataTransformerInlineFormset(
-                    instance=self.instance,
-                    data=self.data if self.is_bound else None,
-                    files=self.files if self.is_bound else None
-                )
-                self.nested_data_transformer_form.extra = 0
 
         except Exception as e:
             print(str(e))
             self.nested_data_transformer_form = dataTransformerInlineFormset(
                 instance=self.instance,
                 data=self.data if self.is_bound else None,
-                files=self.files if self.is_bound else None
+                files=self.files if self.is_bound else None,
+                prefix=self.instance.id
             )
             self.nested_data_transformer_form.extra = 0
 
@@ -592,7 +583,9 @@ class DataTransform(forms.ModelForm):
             queryset=self.instance.datatransformerconstants_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'id': str(uuid.uuid4())}]
+            prefix=self.instance.id,
+            extra=self.instance.datatransformerconstants_set.count() + 1,
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
 
@@ -601,8 +594,9 @@ class DataTransform(forms.ModelForm):
             queryset=self.instance.hardwaredatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'id': str(uuid.uuid4())}]
-
+            prefix=self.instance.id,
+            extra=self.instance.hardwaredatatransformer_set.count() + 1,
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
         )
 
         self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
@@ -610,7 +604,9 @@ class DataTransform(forms.ModelForm):
             queryset=self.instance.hardwarestatsdatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'id': str(uuid.uuid4())}]
+            prefix=self.instance.id,
+            extra=self.instance.hardwarestatsdatatransformer_set.count() + 1,
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
 
@@ -706,7 +702,8 @@ class DataTransformRoot(forms.ModelForm):
                     queryset=self.instance.get_children(),
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
-                    initial=[{'parent': self.instance, 'accessory': self.instance.accessory, 'id': str(uuid.uuid4())}]
+                    initial=[{'parent': self.instance, 'accessory': self.instance.accessory, 'id':str(uuid.uuid4())}],
+                    prefix=self.instance.id
                 )
                 self.nested_data_transformer_form.extra = self.instance.get_children().count() + 1
 
@@ -715,7 +712,8 @@ class DataTransformRoot(forms.ModelForm):
                 self.nested_data_transformer_form = dataTransformerInlineFormset(
                     instance=self.instance,
                     data=self.data if self.is_bound else None,
-                    files=self.files if self.is_bound else None
+                    files=self.files if self.is_bound else None,
+                    prefix=self.instance.id
                 )
                 self.nested_data_transformer_form.extra = 0
         except Exception as e:
@@ -726,7 +724,9 @@ class DataTransformRoot(forms.ModelForm):
             queryset=self.instance.datatransformerconstants_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'id': str(uuid.uuid4())}]
+            prefix=self.instance.id,
+            extra=self.instance.datatransformerconstants_set.count() + 1,
+            initial=[{'data_transformer':self.instance,'id':str(uuid.uuid4())}]
 
         )
 
@@ -735,8 +735,9 @@ class DataTransformRoot(forms.ModelForm):
             queryset=self.instance.hardwaredatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'id': str(uuid.uuid4())}]
-
+            prefix=self.instance.id,
+            extra=self.instance.hardwaredatatransformer_set.count() + 1,
+            initial=[{'data_transformer':self.instance,'id':str(uuid.uuid4())}]
         )
 
         self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
@@ -744,7 +745,9 @@ class DataTransformRoot(forms.ModelForm):
             queryset=self.instance.hardwarestatsdatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'id': str(uuid.uuid4())}]
+            prefix=self.instance.id,
+            extra=self.instance.hardwarestatsdatatransformer_set.count() + 1,
+            initial=[{'data_transformer':self.instance,'id':str(uuid.uuid4())}]
 
         )
 
